@@ -25,9 +25,11 @@ import android.content.Intent;
 import android.os.Build;
 import android.os.Bundle;
 import android.os.Handler;
+import android.os.Looper;
 import android.os.Message;
 import android.support.design.widget.FloatingActionButton;
 import android.support.design.widget.TabLayout;
+import android.support.v4.app.FragmentManager;
 import android.support.v4.view.PagerAdapter;
 import android.support.v4.view.ViewPager;
 import android.view.ContextMenu;
@@ -57,6 +59,7 @@ import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.MainActivity;
 import org.videolan.vlc.gui.SecondaryActivity;
 import org.videolan.vlc.gui.browser.MediaBrowserFragment;
+import org.videolan.vlc.gui.dialogs.SavePlaylistDialog;
 import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.helpers.MediaComparators;
 import org.videolan.vlc.gui.helpers.UiTools;
@@ -213,7 +216,8 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
             }
 
             @Override
-            public void onTabUnselected(TabLayout.Tab tab) {}
+            public void onTabUnselected(TabLayout.Tab tab) {
+            }
 
             @Override
             public void onTabReselected(TabLayout.Tab tab) {
@@ -275,6 +279,7 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
                 mSwipeRefreshLayout.setEnabled(current.getFirstVisiblePosition() == 0);
             }
         });
+        updatePlaylists();
     }
 
     private void focusHelper(final boolean idIsEmpty, final int listId) {
@@ -447,25 +452,35 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
     }
 
     private boolean handleContextItemSelected(final MenuItem item, final int position) {
-
-        int startPosition;
+        final AudioBrowserListAdapter adapter;
         int mode = mViewPager.getCurrentItem();
-        List<MediaWrapper> medias;
+        switch (mode) {
+            case MODE_SONG:
+                adapter = mSongsAdapter;
+                break;
+            case MODE_ALBUM:
+                adapter = mAlbumsAdapter;
+                break;
+            case MODE_ARTIST:
+                adapter = mArtistsAdapter;
+                break;
+            case MODE_PLAYLIST:
+                adapter = mPlaylistAdapter;
+                break;
+            case MODE_GENRE:
+                adapter = mGenresAdapter;
+                break;
+            default:
+                return false;
+        }
+        if (position < 0 && position >= adapter.getCount())
+            return false;
+
         int id = item.getItemId();
 
-        boolean useAllItems = id == R.id.audio_list_browser_play_all;
-        boolean append = id == R.id.audio_list_browser_append;
-
         if (id == R.id.audio_list_browser_delete) {
-            final AudioBrowserListAdapter adapter;
-            if (mode == MODE_SONG){
-                adapter = mSongsAdapter;
-            } else if (mode == MODE_PLAYLIST) {
-                adapter = mPlaylistAdapter;
-            } else
-                return false;
             List<MediaWrapper> mediaList = adapter.getMedias(position);
-            if (adapter.getCount() <= position || mediaList == null || mediaList.isEmpty())
+            if (mediaList == null || mediaList.isEmpty())
                 return false;
             final MediaWrapper media = mediaList.get(0);
             final AudioBrowserListAdapter.ListItem listItem = adapter.getItem(position);
@@ -516,6 +531,24 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
                 return true;
         }
 
+        if (id == R.id .audio_view_add_playlist) {
+            FragmentManager fm = getActivity().getSupportFragmentManager();
+            SavePlaylistDialog savePlaylistDialog = new SavePlaylistDialog();
+            Bundle args = new Bundle();
+            args.putParcelableArrayList(SavePlaylistDialog.KEY_NEW_TRACKS, adapter.getMedias(position));
+            savePlaylistDialog.setArguments(args);
+            savePlaylistDialog.setCallBack(updatePlaylists);
+            savePlaylistDialog.show(fm, "fragment_add_to_playlist");
+            return true;
+        }
+
+        int startPosition;
+        ArrayList<MediaWrapper> medias;
+
+        boolean useAllItems = id == R.id.audio_list_browser_play_all;
+        boolean append = id == R.id.audio_list_browser_append;
+
+        // Play/Append
         if (useAllItems) {
             if (mSongsAdapter.getCount() <= position)
                 return false;
@@ -523,32 +556,14 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
             startPosition = mSongsAdapter.getListWithPosition(medias, position);
         } else {
             startPosition = 0;
-            AudioBrowserListAdapter adapter;
-            switch (mode){
-                case MODE_SONG:
-                    adapter = mSongsAdapter;
-                    break;
-                case MODE_ARTIST:
-                    adapter = mArtistsAdapter;
-                    break;
-                case MODE_ALBUM:
-                    adapter = mAlbumsAdapter;
-                    break;
-                case MODE_GENRE:
-                    adapter = mGenresAdapter;
-                    break;
-                case MODE_PLAYLIST: //For file playlist, we browse tracks with mediabrowser, and add them in callbacks onMediaAdded and onBrowseEnd
+            if (mode == MODE_PLAYLIST){ //For file playlist, we browse tracks with mediabrowser, and add them in callbacks onMediaAdded and onBrowseEnd
                     medias = mPlaylistAdapter.getMedias(position);
                     if (medias.size() == 1 && mPlaylistAdapter.getMedias(position).get(0).getType() == MediaWrapper.TYPE_PLAYLIST) {
                         if (mMediaBrowser == null)
                             mMediaBrowser = new MediaBrowser(VLCInstance.get(), this);
                         mMediaBrowser.browse(mPlaylistAdapter.getMedias(position).get(0).getUri(), true);
                         return true;
-                    } else
-                        adapter = mPlaylistAdapter;
-                    break;
-                default:
-                    return false;
+                    }
             }
             if (position >= adapter.getCount())
                 return false;
@@ -869,6 +884,14 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
     Runnable updatePlaylists = new Runnable() {
         @Override
         public void run() {
+            if (Looper.myLooper() != Looper.getMainLooper()) {
+                mHandler.post(new Runnable() {
+                    @Override
+                    public void run() {
+                        mPlaylistAdapter.clear();
+                    }
+                });
+            }
             //File playlists
             ArrayList<MediaWrapper> playlists = mMediaLibrary.getPlaylistFilesItems();
             mPlaylistAdapter.addAll(playlists, AudioBrowserListAdapter.TYPE_PLAYLISTS);
@@ -882,6 +905,10 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
         }
     };
 
+    private void updatePlaylists() {
+        VLCApplication.runBackground(updatePlaylists);
+    }
+
     AudioBrowserListAdapter.ContextPopupMenuListener mContextPopupMenuListener
             = new AudioBrowserListAdapter.ContextPopupMenuListener() {
 
