@@ -66,9 +66,10 @@ import org.videolan.vlc.util.VLCInstance;
 import org.videolan.vlc.util.WeakHandler;
 
 import java.util.ArrayList;
+import java.util.LinkedList;
 
 
-public abstract class BaseBrowserFragment extends MediaBrowserFragment implements IRefreshable, MediaBrowser.EventListener, SwipeRefreshLayout.OnRefreshListener {
+public abstract class BaseBrowserFragment extends MediaBrowserFragment implements IRefreshable, MediaBrowser.EventListener, SwipeRefreshLayout.OnRefreshListener, View.OnClickListener {
     protected static final String TAG = "VLC/BaseBrowserFragment";
 
     public static String ROOT = "smb";
@@ -138,6 +139,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         View v = inflater.inflate(getLayoutId(), container, false);
         mRecyclerView = (ContextMenuRecyclerView) v.findViewById(R.id.network_list);
         mEmptyView = (TextView) v.findViewById(android.R.id.empty);
+        mAddDirectoryFAB = (FloatingActionButton) v.findViewById(R.id.fab_add_custom_dir);
         mLayoutManager = new LinearLayoutManager(getActivity());
         mRecyclerView.addItemDecoration(new DividerItemDecoration(VLCApplication.getAppContext(), DividerItemDecoration.VERTICAL_LIST));
         mRecyclerView.setLayoutManager(mLayoutManager);
@@ -316,6 +318,13 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         mAdapter.notifyDataSetChanged();
         parseSubDirectories();
         focusHelper();
+        if (mAdapter.getMediaCount() > 0) {
+            mAddDirectoryFAB.setVisibility(View.VISIBLE);
+            mAddDirectoryFAB.setOnClickListener(this);
+        } else {
+            mAddDirectoryFAB.setVisibility(View.GONE);
+            mAddDirectoryFAB.setOnClickListener(null);
+        }
     }
 
     @Override
@@ -344,6 +353,14 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         });
     }
 
+    @Override
+    public void onClick(View v) {
+        switch (v.getId()) {
+            case R.id.fab_add_custom_dir:
+                playAll(null);
+        }
+    }
+
     protected static class BrowserFragmentHandler extends WeakHandler<BaseBrowserFragment> {
 
         public static final int MSG_SHOW_LOADING = 0;
@@ -423,6 +440,10 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
             }
         } else {
             inflater.inflate(R.menu.directory_view_file, menu);
+            boolean canPlayInList =  mw.getType() == MediaWrapper.TYPE_AUDIO ||
+                    (mw.getType() == MediaWrapper.TYPE_VIDEO && AndroidUtil.isHoneycombOrLater());
+            menu.findItem(R.id.directory_view_play_all).setVisible(canPlayInList);
+            menu.findItem(R.id.directory_view_append).setVisible(canPlayInList);
             menu.findItem(R.id.directory_view_delete).setVisible(canWrite);
             menu.findItem(R.id.directory_view_info).setVisible(type == MediaWrapper.TYPE_VIDEO || type == MediaWrapper.TYPE_AUDIO);
             menu.findItem(R.id.directory_view_play_audio).setVisible(type != MediaWrapper.TYPE_AUDIO);
@@ -450,9 +471,9 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
             return super.onContextItemSelected(item);
         final MediaWrapper mw = (MediaWrapper) mAdapter.getItem(position);
         switch (id){
-            case R.id.directory_view_play:
+            case R.id.directory_view_play_all:
                 mw.removeFlags(MediaWrapper.MEDIA_FORCE_AUDIO);
-                MediaUtils.openMedia(getActivity(), mw);
+                playAll(mw);
                 return true;
             case R.id.directory_view_append: {
                 if (mService != null)
@@ -519,6 +540,23 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         return false;
     }
 
+    private void playAll(MediaWrapper mw) {
+        boolean isHoneycombOrLater = AndroidUtil.isHoneycombOrLater();
+        int positionInPlaylist = 0;
+        LinkedList<MediaWrapper> mediaLocations = new LinkedList<>();
+        MediaWrapper media;
+        for (Object file : mAdapter.getAll())
+            if (file instanceof MediaWrapper) {
+                media = (MediaWrapper) file;
+                if ((isHoneycombOrLater && media.getType() == MediaWrapper.TYPE_VIDEO) || media.getType() == MediaWrapper.TYPE_AUDIO) {
+                    mediaLocations.add(media);
+                    if (mw != null && media.equals(mw))
+                        positionInPlaylist = mediaLocations.size() - 1;
+                }
+            }
+        MediaUtils.openList(getActivity(), mediaLocations, positionInPlaylist);
+    }
+
     protected void parseSubDirectories() {
         if ((mRoot && this instanceof NetworkBrowserFragment) || mCurrentParsedPosition == -1 ||
                 mAdapter.isEmpty() || this instanceof FilePickerFragment)
